[LNT] r178557 - Changed the daily report ui so that you can set the day_start argument via an html query string.

Michael Gottesman mgottesman at apple.com
Tue Apr 2 11:24:27 PDT 2013


Author: mgottesman
Date: Tue Apr  2 13:24:26 2013
New Revision: 178557

URL: http://llvm.org/viewvc/llvm-project?rev=178557&view=rev
Log:
Changed the daily report ui so that you can set the day_start argument via an html query string.

Modified:
    lnt/trunk/lnt/server/ui/views.py

Modified: lnt/trunk/lnt/server/ui/views.py
URL: http://llvm.org/viewvc/llvm-project/lnt/trunk/lnt/server/ui/views.py?rev=178557&r1=178556&r2=178557&view=diff
==============================================================================
--- lnt/trunk/lnt/server/ui/views.py (original)
+++ lnt/trunk/lnt/server/ui/views.py Tue Apr  2 13:24:26 2013
@@ -818,12 +818,18 @@ def v4_daily_report(year, month, day):
         num_days = int(num_days_str)
     else:
         num_days = 3
-
+    
+    day_start_str = request.args.get('day_start')
+    if day_start_str is not None:
+        day_start = int(day_start_str)
+    else:
+        day_start = 16
+    
     ts = request.get_testsuite()
 
     # Create the report object.
     report = lnt.server.reporting.dailyreport.DailyReport(
         ts, year, month, day, num_days)
 
     # Build the report.
     report.build()
@@ -818,12 +818,18 @@ def v4_daily_report(year, month, day):
     # Create the report object.
     report = lnt.server.reporting.dailyreport.DailyReport(
-        ts, year, month, day, num_days)
+        ts, year, month, day, num_days, day_start)
 
     # Build the report.





More information about the llvm-commits mailing list